docs.rs failed to build libxfce4util-sys-0.1.0
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
libxfce4util-sys
This crate provides FFI bindings for libxfce4util, a utility library
for Xfce applications.
In general you will not need to use this crate, and will instead want to use xfce4-util instead.